---
elm:
  dependencies:
    avh4/elm-fifo: latest
    elm/browser: latest
    elm/core: latest
    elm/html: latest
    elm/json: latest
    elm/parser: latest
    elm/regex: latest
    elm/time: latest
    elm/url: latest
    elm/virtual-dom: latest
    elm-community/graph: latest
    elm-community/intdict: latest
    elm-community/list-extra: latest
    elm-community/maybe-extra: latest
    elm-community/string-extra: latest

  source-directories:
    - ../src
---

# Problema del oro en la isla

> Fuente: Ejercios de Lógica Computacional
> (https://www.cs.us.es/~fsancho/?p=logica-informatica-2020-21)

En una isla habitan dos tribus de nativos, $A$ y $B$. Todos los miembros de la tribu $A$ siempre dicen la verdad, mientras que todos los de la tribu $B$ siempre mienten. Llegamos a esta isla y le preguntamos a un nativo si allí hay oro, a lo que nos responde:

<center>

_Hay oro en la isla si y sólo si yo siempre digo la verdad_

</center>

¿Hay oro en la isla? ¿Podemos determinar a qué tribu pertenece el nativo que nos respondió?

## Solución

Sea $p_i$ una variable proposicional que indica si el letrero de dicha puerta es verdadero.

```elm {l context="1"}
import LogicUS.PL.SintaxSemantics exposing (..)
import LogicUS.PL.SemanticTableaux exposing (..)
```

Sea la variable proposicional $v$ que expresa si el habitante dice o no la verdad y sea $o$ una varible proposicional que indica si hay oro en la isla. Podemos modelar lo expresado por el habitante como:

$$v \leftrightarrow o$$

Pero eso será cierto si y sólo si el habitante decía la verdad, por tanto, tendríamos:

$$(v \leftrightarrow o) \leftrightarrow v$$

Ahora, hemos de determinar si hay oro en la isla, si no o si no se puede saber. Esto es si se da alguna de las siguientes, o no:

$$(v \leftrightarrow o) \leftrightarrow v \models o \quad\quad \textit{ ó } \quad\quad (v \leftrightarrow o) \leftrightarrow v \models \neg o$$

Veamos con la primera. De forma que hemos de probar la inconsistencia del conjunto $\{(v \leftrightarrow o) \leftrightarrow v, \neg o\}$. Hagámoslo en LogicUS, mediante el uso de tableros:

```elm {l context="1" id="1"}
f1 : FormulaPL
f1 = fplReadExtraction <| fplReadFromString <| "(v <-> o) <-> v"

f2 : FormulaPL
f2 = Atom "o"
```

Ahora construyamos el árbol y generemos la representación en DOT.

```elm {l context="1"}
st1 : String
st1 = (semanticTableau [f1, Neg f2] |> semanticTableauToDOT)
```

```dot
digraph G {
rankdir=TB
graph []
node [shape=box, color=black]
edge [dir=none, color=blue, fontcolor=blue]

0 -> 1 [label="α (1)"]
1 -> 2 [label="β (2)"]
1 -> 9 [label="β (2)"]
2 -> 3 [label="β (2)"]
2 -> 8 [label="β (2)"]
3 -> 4 [label="β (2)"]
3 -> 6 [label="β (2)"]
4 -> 5 [label="α (3)"]
5 -> 15 [label="I (2, 3)"]
6 -> 7 [label="α (3)"]
7 -> 16 [label="I (1, 3)"]
8 -> 17 [label="I (2, 3)"]
9 -> 10 [label="β (2)"]
9 -> 11 [label="β (2)"]
10 -> 18 [label="I (2, 3)"]
11 -> 12 [label="α (3)"]
12 -> 13 [label="β (3)"]
12 -> 14 [label="β (3)"]
13 -> 19 [label="I (2, 4)"]
14 -> 20 [label="I (1, 4)"]

0 [label="{( ( v ↔ o ) ↔ v ), ¬ o}"] 1 [label="{¬ o, ( ( v ↔ o ) → v ), ( v → ( v ↔ o ) )}"]
2 [label="{¬ o, ( v → ( v ↔ o ) ), ¬ ( v ↔ o )}"]
3 [label="{¬ o, ¬ ( v ↔ o ), ¬ v}"]
4 [label="{¬ o, ¬ v, ¬ ( v → o )}"]
5 [label="{¬ o, ¬ v, v}"]
6 [label="{¬ o, ¬ v, ¬ ( o → v )}"]
7 [label="{¬ o, ¬ v, o}"]
8 [label="{¬ o, ¬ ( v ↔ o ), ( v ↔ o )}"]
9 [label="{¬ o, ( v → ( v ↔ o ) ), v}"]
10 [label="{¬ o, v, ¬ v}"]
11 [label="{¬ o, v, ( v ↔ o )}"]
12 [label="{¬ o, v, ( v → o ), ( o → v )}"]
13 [label="{¬ o, v, ( o → v ), ¬ v}"]
14 [label="{¬ o, v, ( o → v ), o}"]
15 [label="×"]
16 [label="×"]
17 [label="×"]
18 [label="×"]
19 [label="×"]
20 [label="×"]
}
```

El tablero es cerrado por tanto el conjunto es insatisfactible y por tanto, podemos asegurar que hay oro en la isla. Ahora, ¿podemos asegurar si el habitante pertenecía a la tribu $A$ o a la tribu $B$? Veámos que no. Calculemos los modelos de $$(v \leftrightarrow o) \leftrightarrow v$$ y veamos que $v$ puede valer tanto $F$ como $V$. Para ello, calculemos el tablero (ahora sin mostrarlo) y calculemos los modelos a través del mismo:

```elm {l m context="1"}
st2 : String
st2 =
  "$$" ++
    (interpretationsToMathString
      ( semanticTableau [f1] |>  semanticTableauModels)
      ["v", "o"]
    )
    ++ "$$"
```

Como habíamos adelantado, obtenemos dos modelos, uno en el que $v$ es verdadero (el habitante pertenecería a $A$) y otra en el que $v$ es falso (el habitante pertenecería a $B$). Por tanto no se puede saber a qué tribu pertenecía el habitante.
